---------------------------------------------------------------
--                                                           
--  ROBOT INTERPRETER
--  By: Martin Carlisle and Keith Shomper     
--                                                           
--  ROBOT_INTERPRETER.ADB 
--  Description : Main procedure 
--                       
--  By: Martin Carlisle
--                                         
-- ROBOT INTERPRETER is free software; you can redistribute it and/or 
-- modify it without restriction.  However, we ask that you
-- please retain the original author information, and clearly  
-- indicate if it has been modified.
--  
-- ROBOT INTERPRETER is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
--
---------------------------------------------------------------
with Main_Window;
with Ada.Exceptions;
with Mcc.Gui.Container.Window;
with Mcc.Common_Dialogs;
with Robot_Menu;
with Robot_Helpers;
with Simulation_GUI;
with Mcc.Gui.Event_Scheduler;
with ada.text_io;
with RoomADT;
with State;
with Room_Dialog;
with Ada.Command_Line;
use Ada.Command_Line;
procedure Robot_Interpreter is

begin
   Main_Window.Generate_Window;
   RoomADT.Create(
      R         => State.Room, 
      Size      => Room_Dialog.Room_Size, 
      Num_Doors => 3);
   Simulation_Gui.Initialize;
   
   if Argument_Count = 1 then
      Robot_Menu.Open_File(Argument(1));
   end if;

   -- set minimum window size
   Mcc.Gui.Container.Window.Set_Resize_Handler(
      Obj     => main_Window.main_Window'access,
      Handler => Robot_Helpers.Robot_Resize_Handler'access);

   Mcc.Gui.Container.Window.Set_Close_Handler(
      Obj     => Main_Window.Main_Window'access,
      Handler => Robot_Menu.Exit_Choice'access);
   Mcc.Gui.Container.Window.Event_Loop;
exception when E:others =>
   Mcc.Common_Dialogs.OK_Box(
      "Uncaught exception -- contact author:" &
      Ada.Exceptions.Exception_Information(E));
   raise;
end Robot_Interpreter;