with Adagraph;
with Common;

package room is
   type room_type is private; 
   type boolean_array_type    is array (Positive range <>) of Boolean;
   
   Scale      : constant positive :=  5;
   Tile_Size  : constant positive :=  6 * Scale;
   Offset     : constant positive :=  2 * Tile_Size;
   Door_Width : constant positive :=  2 * Scale;

   procedure create (R : in out room_type; height : Positive; width : Positive; num_doors : Natural);
   procedure create (R : in out room_type; height : Positive; width : Positive; doors : boolean_array_type);
   
   procedure draw(R: room_type);
   procedure draw_tile(X : Natural; Y : Natural);
   
   function Tile_To_Screen_X (X : Natural) return Natural;
   function Tile_To_Screen_Y (Y : Natural) return Natural;
   
   function Tile_Color (X : Positive; Y : Positive) return Adagraph.Extended_Color_Type;
   
   function Height return Positive;
   function Width  return Positive;
   
   function Is_Door (X : Positive; Y : Positive; direction : Common.Direction_Type) return Boolean;
      
   private
   
   max_height            : constant positive := 20;
   max_width             : constant positive := max_height;
   
   max_room_perimeter    : constant positive := max_height * 2 + max_width * 2;
   
   max_doors             : constant positive := max_room_perimeter;
      
   type room_type is record
      height    : positive;
      width     : positive;
      perimeter : positive;
      doors     : boolean_array_type(1..max_doors) := (others => false);
   end record;
end room;