---------------------------------------------------------------
--                                                           
--  ROBOT INTERPRETER
--  By: Martin Carlisle and Keith Shomper     
--                                                           
--  SIMULATION_GUI
--  Description : manually generated GUI objects in main window 
--                       
--  By: Martin Carlisle
--                                         
-- ROBOT INTERPRETER is free software; you can redistribute it and/or 
-- modify it without restriction.  However, we ask that you
-- please retain the original author information, and clearly  
-- indicate if it has been modified.
--  
-- ROBOT INTERPRETER is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
--
---------------------------------------------------------------
with Mcc.Gui.Widget.Label;
with Mcc.Gui.Widget.Picture;
with Mcc.Gui.Image;
package Simulation_Gui is
   Max_Room_Size : constant := 11;
   subtype Room_Size_Type is Natural range 1..Max_Room_Size;
 
   subtype Memory_Location is Natural range 0..31;
   subtype Memory_Value is Natural range 0..255;
   
   type Indexed_Picture is new Mcc.Gui.Widget.Picture.Picture with record
      X,Y : Natural;
   end record;
   
   type Indexed_Label is new Mcc.Gui.Widget.Label.Label with record
      Y : Natural;
   end record;
   
   Location_Labels   : array(Memory_Location) of aliased Indexed_Label;
   Memory_Labels     : array(Memory_Location) of aliased Indexed_Label;
   Instruction_Labels: array(Memory_Location) of Mcc.Gui.Widget.Label.Label;
   Integer_Labels    : array(Memory_Location) of Mcc.Gui.Widget.Label.Label;

   Wavy_NS    : Mcc.Gui.Image.External_Image;
   Wavy_EW    : Mcc.Gui.Image.External_Image;
   Blank_Grid    : Mcc.Gui.Image.External_Image;
   Light_On    : Mcc.Gui.Image.External_Image;
   Light_Off          : Mcc.Gui.Image.External_Image;
   North_On_Up   : Mcc.Gui.Image.External_Image;
   North_On_Down   : Mcc.Gui.Image.External_Image;
   North_Off_Up   : Mcc.Gui.Image.External_Image;
   North_Off_Down   : Mcc.Gui.Image.External_Image;
   South_On_Down   : Mcc.Gui.Image.External_Image;
   South_On_Up   : Mcc.Gui.Image.External_Image;
   South_Off_Down   : Mcc.Gui.Image.External_Image;
   South_Off_Up   : Mcc.Gui.Image.External_Image;
   East_On_Down   : Mcc.Gui.Image.External_Image;
   East_On_Up   : Mcc.Gui.Image.External_Image;
   East_Off_Down   : Mcc.Gui.Image.External_Image;
   East_Off_Up   : Mcc.Gui.Image.External_Image;
   West_On_Down   : Mcc.Gui.Image.External_Image;
   West_On_Up   : Mcc.Gui.Image.External_Image;
   West_Off_Down   : Mcc.Gui.Image.External_Image;
   West_Off_Up   : Mcc.Gui.Image.External_Image;

   -- pictures of walls, the robot, the grid
   Room : array(0..Max_Room_Size+1,0..Max_Room_Size+1) of 
      aliased Indexed_Picture;      
      
   -------------------------------------------------------
   -- Set_Instruction
   --
   -- moves the arrow to the memory location specified
   -------------------------------------------------------
   procedure Set_Instruction(Which : in Memory_Location);
   
   -------------------------------------------------------
   -- Set_Room_Size
   --
   -- update GUI to reflect new room size.  If the robot
   -- is out of the room, then put him in the lower left
   -- corner (1,1).  Number_Doors creates this number
   -- of random doors
   -------------------------------------------------------
   procedure Set_Room_Size(Size : in Room_Size_Type; 
      Number_Doors : in Natural);

   -------------------------------------------------------
   -- Initialize
   --
   -- draw all of the labels with memory all set to 0
   -- and a room of size Max_Room_Size and the robot in the 
   -- lower left corner.  Only call this once, or
   -- Already_Initialized will be raised.
   -------------------------------------------------------
   Already_Initialized : exception;
   procedure Initialize;
   
   -------------------------------------------------------
   -- call Erase_Robot if robot about to move.
   -- after move, call draw_robot
   -------------------------------------------------------
   procedure Draw_Robot;
   procedure Erase_Robot;

   
   --------------------------------------------------------
   -- redraw the entire room
   --------------------------------------------------------
   procedure Draw_Room;
   
   --------------------------------------------------------
   -- call when a new program has been loaded to display it
   --------------------------------------------------------
   procedure Display_Instructions;
   
   --------------------------------------------------------
   -- get 5 bit binary string
   --------------------------------------------------------
   function Five_Bit_Binary(X : in Memory_Location) return String;
end Simulation_Gui;